# Touch response

`touch_response` eklentisi dokunma ya da fare tıklaması ile yanıtlara kolay yoldan görüntüyü satır ve sütunlara ayırarak izin verir. Her bir yanıt soldan sağa ve yukarıdan aşağıya olarak görüntünün neresine dokunulduğunu ya da tıklanıldığını bir sayısal değer olarak kaydeder. Eğer 2 sütun ve 3 satır belirtirseniz, görüntü aşağıdaki yanıt bölgelerine ayrılır:

	1	2
	3	4
	5	6

Benzer olarak, 4 sütun ve 1 satır belirlerseniz, görüntü yatay olarak aşağıdaki bölgelere ayrılır:

	1	2	3	4
